'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

require('../setup/index.js');
require('../utils/click/isClickableInput.js');
require('../utils/dataTransfer/Clipboard.js');
require('../event/eventMap.js');
require('../event/behavior/click.js');
require('../event/behavior/cut.js');
require('../event/behavior/keydown.js');
require('../event/behavior/keypress.js');
require('../event/behavior/keyup.js');
require('../event/behavior/paste.js');
require('@testing-library/dom');
var input = require('../utils/edit/input.js');
var isEditable = require('../utils/edit/isEditable.js');
var focus = require('../utils/focus/focus.js');
require('@testing-library/dom/dist/helpers.js');
var isDisabled = require('../utils/misc/isDisabled.js');
var selectAll = require('../utils/focus/selectAll.js');
require('../utils/keyDef/readNextDescriptor.js');
require('../utils/misc/level.js');
require('../options.js');
var config = require('../setup/config.js');

async function clear(element) {
    if (!isEditable.isEditable(element) || isDisabled.isDisabled(element)) {
        throw new Error('clear()` is only supported on editable elements.');
    }
    focus.focus(element);
    if (element.ownerDocument.activeElement !== element) {
        throw new Error('The element to be cleared could not be focused.');
    }
    selectAll.selectAll(element);
    if (!selectAll.isAllSelected(element)) {
        throw new Error('The element content to be cleared could not be selected.');
    }
    input.input(this[config.Config], element, '', 'deleteContentBackward');
}

exports.clear = clear;
